@@ -1,8 +1,10 @@
 import threading
 
+from pkg_resources import iter_entry_points
 import pymongo
 
 from .managers import NodeManager, ActivityManager, Aggregator
+from .storage import pymongostorage
 
 _director = None
 
@@ -10,32 +12,20 @@ _director = None
 class ActivityDirector(threading.local):
     def __init__(self, **conf):
         self.conf = conf
-        if conf['activitystream.master'].startswith('mim://'):
-            try:
-                from ming import mim
-            except ImportError, e:
-                raise ImportError(str(e) + '. To use mim:// you must have the '
-                        'ming package installed.')
-            else:
-                self.connection = mim.Connection()
-        else:
-            self.connection = pymongo.Connection(conf['activitystream.master'])
-        self.db = self.connection[conf['activitystream.database']]
-        self.activity_collection = \
-                self.db[conf['activitystream.activity_collection']]
-        self.timeline_collection = \
-                self.db[conf['activitystream.timeline_collection']]
-        self.node_collection = \
-                self.db[conf['activitystream.node_collection']]
-        self.node_manager = NodeManager(self.node_collection)
-        self.activity_manager = ActivityManager(self.activity_collection,
-                                                self.node_manager)
-        self.timeline_manager = ActivityManager(self.timeline_collection,
-                                                self.node_manager)
+        storage = self._get_storage(conf)
+        self.node_manager = NodeManager(storage)
+        self.activity_manager = ActivityManager(storage, self.node_manager)
         self.aggregator = Aggregator(self.activity_manager,
-                                     self.timeline_manager,
                                      self.node_manager)
 
+    def _get_storage(self, conf):
+        storage_class = None
+        for ep in iter_entry_points(group='activitystream.storage'):
+            storage_class = ep.load()
+            break
+        storage_class = storage_class or pymongostorage.PymongoStorage
+        return storage_class(conf)
+
     def connect(self, follower, following):
         self.node_manager.follow(follower, following)
 
@@ -63,7 +53,6 @@ def configure(**conf):
             'activitystream.database': 'activitystream',
             'activitystream.activity_collection': 'activities',
             'activitystream.node_collection': 'nodes',
-            'activitystream.timeline_collection': 'timelines',
     }
     defaults.update(conf)
     _director = ActivityDirector(**defaults)
